@@ -1,20 +1,7 @@
-/***************************************************************************
-                               kwqquizmodel.h
-                             -------------------
-
-    copyright            : (C) 2008-2010 by Peter Hedlund
-    email                : peter.hedlund@kdemail.net
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KWQQUIZMODEL_H
 #define KWQQUIZMODEL_H
@@ -79,7 +66,7 @@ public:
     QList<int> errorList() const {return m_errorList;}
     void removeLastError();
 
-signals:
+Q_SIGNALS:
   void checkingAnswer(int );
 
 protected:
